package temperature

import (
	"fmt"
	"log"
	"os"

	"github.com/spf13/cobra"
	"github.com/volker-raschek/flucky/pkg/cli"
	"github.com/volker-raschek/flucky/pkg/config"
	"github.com/volker-raschek/flucky/pkg/sensor"
)

var logs bool

var readTemperatureCmd = &cobra.Command{
	Use:     "read",
	Short:   "read temperature from sensor",
	Example: fmt.Sprintf("flucky temperature read\nflucky temperature read outdoor"),
	Run: func(cmd *cobra.Command, args []string) {

		// read configuration
		cnf, err := config.Read(cnfPath)
		if err != nil {
			log.Fatalln(err)
		}

		// fetch all temperature sensors
		temperatureSensors := cnf.GetTemperatureSensors()

		// read temperature from sensors
		temperatures, err := sensor.ReadTemperatures(temperatureSensors)
		if err != nil {
			log.Fatalln(err)
		}

		// print temperatures on stdout
		cli.PrintTemperatures(temperatures, cnf, os.Stdout)
	},
}

func init() {
	temperatureCmd.AddCommand(readTemperatureCmd)
	// readTemperatureCmd.Flags().BoolVarP(&follow, "follow", "f", false, "Follow output")
	readTemperatureCmd.Flags().BoolVarP(&logs, "logs", "l", true, "Log temperature")
}
